<?php

namespace Litecms\Testimonial\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Testimonial\Interfaces\TestimonialRepositoryInterface;
use Litecms\Testimonial\Repositories\Eloquent\Filters\TestimonialPublicFilter;
use Litecms\Testimonial\Repositories\Eloquent\Presenters\TestimonialListPresenter;

class TestimonialPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        TestimonialRepositoryInterface $testimonial
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.testimonial.modules'), 'testimonial', guard_url('testimonial'));
        $this->repository = $testimonial;
    }

    /**
     * Show testimonial's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(TestimonialPublicFilter::class)
            ->setPresenter(TestimonialListPresenter::class)
            ->select('testimonials.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('testimonial::testimonial.names'))
            ->view('testimonial::public.testimonial.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show testimonial.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('testimonial::testimonial.name'))
            ->view('testimonial::public.testimonial.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
