<?php

namespace Litecms\Testimonial\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Testimonial\Models\Testimonial;

class TestimonialPolicy
{

    /**
     * Determine if the given user can view the testimonial.
     *
     * @param UserPolicyInterface $authUser
     * @param Testimonial $testimonial
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Testimonial $testimonial)
    {
        if ($authUser->canDo('testimonial.testimonial.view') && $authUser->isAdmin()) {
            return true;
        }

        return $testimonial->user_id == user_id() && $testimonial->user_type == user_type();
    }

    /**
     * Determine if the given user can create a testimonial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('testimonial.testimonial.create');
    }

    /**
     * Determine if the given user can update the given testimonial.
     *
     * @param UserPolicyInterface $authUser
     * @param Testimonial $testimonial
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Testimonial $testimonial)
    {
        if ($authUser->canDo('testimonial.testimonial.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $testimonial->user_id == user_id() && $testimonial->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given testimonial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Testimonial $testimonial)
    {
        return $testimonial->user_id == user_id() && $testimonial->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given testimonial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Testimonial $testimonial)
    {
        if ($authUser->canDo('testimonial.testimonial.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given testimonial.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Testimonial $testimonial)
    {
        if ($authUser->canDo('testimonial.testimonial.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
